const blessed = require("blessed");
class Box {
  static build(options, screen) {
    const { content } = options;
    const box = blessed.box({
      top: "center",
      left: "center",
      width: options.width || "50%",
      height: options.height || "50%",
      content,
      tags: true,
      border: {
        type: "line",
      },
      style: {
        fg: "white",
        bg: "magenta",
        border: {
          fg: "#f0f0f0",
        },
      },
    });
    if (screen) {
      screen.append(box);
    }
    return box;
  }
}

class Form {
  static build(model, options, screen) {
    const form = blessed.form({
      parent: options.parent || screen,
      keys: true,
      left: 0,
      top: 0,
      width: 30,
      height: 4,
      bg: "magenta",
      content: "Submit or cancel?",
    });

    const submit = blessed.button({
      parent: form,
      mouse: true,
      keys: true,
      shrink: true,
      padding: {
        left: 1,
        right: 1,
      },
      left: 10,
      top: 2,
      shrink: true,
      name: "submit",
      content: "submit",
      style: {
        bg: "blue",
        focus: {
          bg: "red",
        },
        hover: {
          bg: "red",
        },
      },
    });

    const cancel = blessed.button({
      parent: form,
      mouse: true,
      keys: true,
      shrink: true,
      padding: {
        left: 1,
        right: 1,
      },
      left: 20,
      top: 2,
      shrink: true,
      name: "cancel",
      content: "cancel",
      style: {
        bg: "blue",
        focus: {
          bg: "red",
        },
        hover: {
          bg: "red",
        },
      },
    });

    submit.on("press", function () {
      form.submit();
    });

    cancel.on("press", function () {
      form.reset();
    });

    form.on("submit", function (data) {
      form.setContent("Submitted.");
      screen.render();
    });

    form.on("reset", function (data) {
      form.setContent("Canceled.");
      screen.render();
    });
    return form;
  }
}

const Banner = `

     dP                                                               dP
     88                                                               88
     88d888b. dP    dP 88d888b. .d8888b. 88d888b. 88d888b. .d8888b. d8888P
     88'  \`88 88    88 88'  \`88 88ooood8 88'  \`88 88'  \`88 88ooood8   88
     88    88 88.  .88 88.  .88 88.  ... 88       88    88 88.  ...   88
     dP    dP \`8888P88 88Y888P' \`88888P' dP       dP    dP \`88888P'   dP
                   .88 88
               d8888P  dP
`;

module.exports = { Box, Form, Banner };
